# jax-decision-making

[![PyPI - Version](https://img.shields.io/pypi/v/jax-decision-making.svg)](https://pypi.org/project/jax-decision-making)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/jax-decision-making.svg)](https://pypi.org/project/jax-decision-making)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install jax-decision-making
```

## License

`jax-decision-making` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
